@@ -1,14 +1,16 @@
 from inspect import Signature
-from typing import Any, Dict, List, Optional, Type, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union, cast
 
 from pydantic import validate_arguments
-from pydantic.typing import AnyCallable
 
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.handlers.base import BaseRouteHandler
 from starlite.types import ExceptionHandler, Guard
 from starlite.utils import is_async_callable
 
+if TYPE_CHECKING:
+    from pydantic.typing import AnyCallable
+
 
 class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
     @validate_arguments(config={"arbitrary_types_allowed": True})
@@ -22,7 +24,7 @@ class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
     ):
         super().__init__(path=path, guards=guards, opt=opt, exception_handlers=exception_handlers)
 
-    def __call__(self, fn: AnyCallable) -> "ASGIRouteHandler":
+    def __call__(self, fn: "AnyCallable") -> "ASGIRouteHandler":
         """
         Replaces a function with itself
         """
@@ -35,7 +37,7 @@ class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
         Validates the route handler function once it's set by inspecting its return annotations
         """
         super().validate_handler_function()
-        signature = Signature.from_callable(cast(AnyCallable, self.fn))
+        signature = Signature.from_callable(cast("AnyCallable", self.fn))
 
         if signature.return_annotation is not None:
             raise ImproperlyConfiguredException("ASGI handler functions should return 'None'")
