@@ -364,6 +364,6 @@ def get_signature_model(value: Any) -> Type[SignatureModel]:
     Helper function to retrieve and validate the signature model from a provider or handler
     """
     try:
-        return cast(Type[SignatureModel], getattr(value, "signature_model"))
+        return cast("Type[SignatureModel]", getattr(value, "signature_model"))
     except AttributeError as e:  # pragma: no cover
         raise ImproperlyConfiguredException(f"The 'signature_model' attribute for {value} is not set") from e
